@@ -1,3 +1,4 @@
+import select
 import sys
 from typing import List
 from yakh.key._key import Key
@@ -15,16 +16,16 @@ try:
     __unconsumed_chars: List[str] = []
 
     # Adapted from: https://stackoverflow.com/a/59159112/9019559
-    def __break_on_char(imput_str: str) -> List[str]:
+    def __break_on_char(input_str: str) -> List[str]:
         pos = 0
         result = []
-        for m in __ANSICODE.finditer(imput_str):
-            text = imput_str[pos : m.start()]
+        for m in __ANSICODE.finditer(input_str):
+            text = input_str[pos : m.start()]
             result.extend(list(text))
             result.append(m.group())
             pos = m.end()
 
-        text = imput_str[pos:]
+        text = input_str[pos:]
         result.extend(list(text))
         return result
 
@@ -36,14 +37,12 @@ try:
         tty.setraw(fd_input)
         ch_str = ""
         try:
+            select.select([sys.stdin], [], [], None)
             while True:
-                if ch_str != "":
+                ch_stri = sys.stdin.read(1)
+                if ch_stri == "":
                     break
-                while True:
-                    ch_stri = sys.stdin.read(1)
-                    if ch_stri == "":
-                        break
-                    ch_str += ch_stri
+                ch_str += ch_stri
         except Exception:
             pass
         finally:
